# recept

`recept` is a command line tool for running recipes and a library of useful
function for writing your own recipes.

You can create your own recipes in the `recipes` module of your application
folder and run them using the recipe runner command `rr`.

Also you can use the rich library of recipe functions for writing your recipes.

